# Changelog

## 0.16.0 (2026-01-30)

Full Changelog: [v0.15.0...v0.16.0](https://github.com/ArkHQ-io/ark-python/compare/v0.15.0...v0.16.0)

### Features

* **api:** api update ([56309b8](https://github.com/ArkHQ-io/ark-python/commit/56309b8f34212923562d01dbad53df307d1a6a97))
* **api:** manual updates ([a6fdf54](https://github.com/ArkHQ-io/ark-python/commit/a6fdf54cba7744137502a2e97f9105ef204f4d79))

## 0.15.0 (2026-01-30)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/ArkHQ-io/ark-python/compare/v0.14.0...v0.15.0)

### Features

* **api:** api update ([0f5c166](https://github.com/ArkHQ-io/ark-python/commit/0f5c1666d7c02d1f18096610716be6cb2c39a281))
* **api:** api update ([f128894](https://github.com/ArkHQ-io/ark-python/commit/f128894ef84fffa757424b4b1684f7e4eebf4629))
* **api:** manual updates ([bcc7230](https://github.com/ArkHQ-io/ark-python/commit/bcc72308bfbfd6bfd6cefc6df9e1019637ce1b02))
* **api:** manual updates ([378cd65](https://github.com/ArkHQ-io/ark-python/commit/378cd65aadfd41edd36f4d82ad3ea12d95ec8f0c))
* **api:** manual updates ([edb503c](https://github.com/ArkHQ-io/ark-python/commit/edb503c58439ac4face4260cf1e6794cab79f8bb))
* **client:** add custom JSON encoder for extended type support ([ff51eb2](https://github.com/ArkHQ-io/ark-python/commit/ff51eb229a2eda74e3bc8c16d5f7f43758dc5c31))

## 0.14.0 (2026-01-29)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/ArkHQ-io/ark-python/compare/v0.13.0...v0.14.0)

### Features

* **api:** add usage and SendLimit Headers ([4281980](https://github.com/ArkHQ-io/ark-python/commit/4281980353ff7423dbc6627e37abefee952bc489))
* **api:** api update ([10f496a](https://github.com/ArkHQ-io/ark-python/commit/10f496a29924ecd9bcc93d0551ea8bd29662aa89))
* **api:** domain list improvement ([6929689](https://github.com/ArkHQ-io/ark-python/commit/69296893c13ad8e4f05047f312009e88a8f02830))


### Bug Fixes

* **docs:** fix mcp installation instructions for remote servers ([f559107](https://github.com/ArkHQ-io/ark-python/commit/f55910772f06f551b98a1ddc7c7dda45fc2176f4))

## 0.13.0 (2026-01-25)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/ArkHQ-io/ark-python/compare/v0.12.0...v0.13.0)

### Features

* **api:** manual updates ([a479b34](https://github.com/ArkHQ-io/ark-python/commit/a479b34c96a0395472f3f5cd0be267de45216762))
* **api:** update email details to include attachments ([041f91e](https://github.com/ArkHQ-io/ark-python/commit/041f91ef9e96ccd47dda255d5a0380ddfece23b0))


### Chores

* **ci:** upgrade `actions/github-script` ([066a689](https://github.com/ArkHQ-io/ark-python/commit/066a6895bd50bea4327966982fca2ea2f94eff8a))

## 0.12.0 (2026-01-23)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/ArkHQ-io/ark-python/compare/v0.11.0...v0.12.0)

### Features

* **api:** fix from in Send raw MIME email ([59d29a6](https://github.com/ArkHQ-io/ark-python/commit/59d29a64079d6e9273f7cde8936b8f2fda4ca48d))
* **api:** improve raw MIME error handling ([0f9682d](https://github.com/ArkHQ-io/ark-python/commit/0f9682db45a4d6014f39df875bc0c56db9420b63))

## 0.11.0 (2026-01-23)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/ArkHQ-io/ark-python/compare/v0.10.0...v0.11.0)

### Features

* **api:** improve raw endpoint ([3ab12b8](https://github.com/ArkHQ-io/ark-python/commit/3ab12b8c773e65632dbc7253e5e37d32883f888a))

## 0.10.0 (2026-01-22)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/ArkHQ-io/ark-python/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([53f3037](https://github.com/ArkHQ-io/ark-python/commit/53f30375a1b5dc65cee68df327e9274c4d2757df))
* **api:** api update ([6a8086f](https://github.com/ArkHQ-io/ark-python/commit/6a8086f22354550011274956066a5d022c34b4fa))
* **api:** fix incorrect webhook payload examples ([e78fd9d](https://github.com/ArkHQ-io/ark-python/commit/e78fd9d83b18f6f887faa36eaefa19140283b780))
* **api:** manual updates ([7570f6e](https://github.com/ArkHQ-io/ark-python/commit/7570f6e225f2eca4a9b6398de0fbddb49483a850))

## 0.9.0 (2026-01-22)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/ArkHQ-io/ark-python/compare/v0.8.0...v0.9.0)

### Features

* **api:** improve GET delivery attempts ([104c580](https://github.com/ArkHQ-io/ark-python/commit/104c5800c67096189bffc9d0db6424ec76d9565b))

## 0.8.0 (2026-01-21)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/ArkHQ-io/ark-python/compare/v0.7.0...v0.8.0)

### Features

* **api:** add sandbox domain ([cb771bb](https://github.com/ArkHQ-io/ark-python/commit/cb771bbc1d85d8cae0c449a716457c46c32ee269))

## 0.7.0 (2026-01-20)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/ArkHQ-io/ark-python/compare/v0.6.0...v0.7.0)

### Features

* **api:** add webhook deliveries ([04005c1](https://github.com/ArkHQ-io/ark-python/commit/04005c15bfdb59f935c056beb9ca1b890a7ba887))
* **api:** api update ([b41a63b](https://github.com/ArkHQ-io/ark-python/commit/b41a63b0f283b8a22479d52d768479d4186181a4))
* **api:** api update ([ce1e30e](https://github.com/ArkHQ-io/ark-python/commit/ce1e30eabcd7011b7baed2fe1d16152373b76371))
* **api:** manual updates ([95d0017](https://github.com/ArkHQ-io/ark-python/commit/95d001788faffe7e232c34ec8732b2dd0e68967a))


### Chores

* **internal:** update `actions/checkout` version ([d91b7db](https://github.com/ArkHQ-io/ark-python/commit/d91b7dbbf43b012cfc86cc7e90730fbf066d9480))

## 0.6.0 (2026-01-14)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/ArkHQ-io/ark-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** add metadata ([81dfc11](https://github.com/ArkHQ-io/ark-python/commit/81dfc11bc8a029f7150e4b72919e084963a7bf0a))
* **client:** add support for binary request streaming ([8f5934e](https://github.com/ArkHQ-io/ark-python/commit/8f5934eb54724933c0558002113d8036e02cf39a))

## 0.5.0 (2026-01-13)

Full Changelog: [v0.4.2...v0.5.0](https://github.com/ArkHQ-io/ark-python/compare/v0.4.2...v0.5.0)

### Features

* **api:** manual updates ([8f402b8](https://github.com/ArkHQ-io/ark-python/commit/8f402b8cc60e0d91f69014ba5d4700f6323df0e1))
* **api:** manual updates ([7c37b87](https://github.com/ArkHQ-io/ark-python/commit/7c37b87cd3a04c518041d1be7f1473c138f3bd54))

## 0.4.2 (2026-01-13)

Full Changelog: [v0.4.1...v0.4.2](https://github.com/ArkHQ-io/ark-python/compare/v0.4.1...v0.4.2)

### Chores

* configure new SDK language ([5fb3ec6](https://github.com/ArkHQ-io/ark-python/commit/5fb3ec6ce80d2486e39a89e84b4a16ac486746b7))

## 0.4.1 (2026-01-13)

Full Changelog: [v0.4.0...v0.4.1](https://github.com/ArkHQ-io/ark-python/compare/v0.4.0...v0.4.1)

### Chores

* update SDK settings ([e071de7](https://github.com/ArkHQ-io/ark-python/commit/e071de7d5303bce685aaee2839f7e9b56c84395c))

## 0.4.0 (2026-01-13)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/ArkHQ-io/ark-python/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([6c4cc66](https://github.com/ArkHQ-io/ark-python/commit/6c4cc666424e3c1a1aac56ec4536cf4ed3537ace))
* **api:** manual updates ([776e67f](https://github.com/ArkHQ-io/ark-python/commit/776e67f921ea69fb2b7dc33322ebef1a1e05b84d))

## 0.3.0 (2026-01-13)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/ArkHQ-io/ark-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([ac4c3d7](https://github.com/ArkHQ-io/ark-python/commit/ac4c3d7059fab55e8da4a9f93ffb3413515129fe))
* **api:** manual updates ([17331e6](https://github.com/ArkHQ-io/ark-python/commit/17331e6d8533aef33fb6984754d8ddbca3aaa994))
* **api:** manual updates ([05fbd0c](https://github.com/ArkHQ-io/ark-python/commit/05fbd0c0683d6b40cf3a9b4d07ee21602a938f4d))
* **api:** manual updates ([5d6498c](https://github.com/ArkHQ-io/ark-python/commit/5d6498c0923a34baa3b8cdc6bd70b92eb122c559))
* **api:** manual updates ([07e7603](https://github.com/ArkHQ-io/ark-python/commit/07e76030e28a03aa1c94cd94fc920e47ccabb13b))
* **api:** manual updates ([d03ff5d](https://github.com/ArkHQ-io/ark-python/commit/d03ff5db9843f7561b8825f4070a3d36da434e61))
* **api:** manual updates ([adc040d](https://github.com/ArkHQ-io/ark-python/commit/adc040df33836303bfeb2e1a255cb8ec6bdaea02))
* **api:** manual updates ([600c059](https://github.com/ArkHQ-io/ark-python/commit/600c05906b89ab47a43f8032dd08ad687dc68473))
* **api:** manual updates ([e41f3fc](https://github.com/ArkHQ-io/ark-python/commit/e41f3fc1143d2125115f063c58e8ea75b60e3479))
* **api:** manual updates ([f54f602](https://github.com/ArkHQ-io/ark-python/commit/f54f60266db5c4fd5b5d6cbb076d5ccc43d30ff1))

## 0.2.0 (2026-01-12)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/ArkHQ-io/ark-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([7690a6d](https://github.com/ArkHQ-io/ark-python/commit/7690a6d828f6adaa02b245f6c88e61aa7846200c))

## 0.1.0 (2026-01-12)

Full Changelog: [v0.0.2...v0.1.0](https://github.com/ArkHQ-io/ark-python/compare/v0.0.2...v0.1.0)

### Features

* **api:** api update ([e46f650](https://github.com/ArkHQ-io/ark-python/commit/e46f650c617e11e1173068ebbb36ac607612e40d))
* **api:** api update ([be470af](https://github.com/ArkHQ-io/ark-python/commit/be470affdcf987f8c0b90aabddee8301593ed41c))

## 0.0.2 (2026-01-12)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/ArkHQ-io/ark-python/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([c32b083](https://github.com/ArkHQ-io/ark-python/commit/c32b08338547890f0b366a0b6b8f38e4c5289b86))
* update SDK settings ([1fc666c](https://github.com/ArkHQ-io/ark-python/commit/1fc666c5a3d8e8f23ca6f3b9824bf9c2ccc0e4a0))
* update SDK settings ([ddfd3fe](https://github.com/ArkHQ-io/ark-python/commit/ddfd3fec94f3badd64b949699772a74790799951))
